@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # Semaphore: A simple (rule-based) bot library for Signal Private Messenger.
-# Copyright (C) 2020 Lazlo Westerhof <semaphore@lazlo.me>
+# Copyright (C) 2020-2021 Lazlo Westerhof <semaphore@lazlo.me>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -17,10 +17,12 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """Semaphore: A simple (rule-based) bot library for Signal Private Messenger."""
 
+from .address import Address
 from .attachment import Attachment
-from .bot import Bot, StopPropagation
+from .bot import Bot
 from .chat_context import ChatContext
 from .data_message import DataMessage
+from .exceptions import StopPropagation
 from .group import Group
 from .groupV2 import GroupV2
 from .job import Job
@@ -31,3 +33,5 @@ from .message_sender import MessageSender
 from .meta import *
 from .reply import Reply
 from .socket import Socket
+from .sticker import Sticker
+from .sticker_pack import StickerPack
