@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # Semaphore: A simple (rule-based) bot library for Signal Private Messenger.
-# Copyright (C) 2020 Lazlo Westerhof <semaphore@lazlo.me>
+# Copyright (C) 2020-2021 Lazlo Westerhof <semaphore@lazlo.me>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -20,6 +20,7 @@ from typing import Optional, TYPE_CHECKING
 
 import attr
 
+from .address import Address
 from .data_message import DataMessage
 from .reply import Reply
 if TYPE_CHECKING:
@@ -32,7 +33,7 @@ class Message:
     """This object represents a Signal message."""
 
     username: str
-    source: str
+    source: Address
     envelope_type: int
     timestamp: int
     timestamp_iso: str
@@ -54,10 +55,6 @@ class Message:
                 return False
         return True
 
-    def get_redacted_source(self) -> str:
-        """Return the message source redacted."""
-        return f"+********{self.source[-3:]}"
-
     def get_body(self):
         """Check if the message is not empty."""
         if self.empty():
@@ -78,13 +75,16 @@ class Message:
                 return self.data_message.group.group_id
         return None
 
-    async def reply(self, *args, **kwargs) -> None:
+    async def reply(self, *args, **kwargs) -> bool:
         """Send a reply to the message.
 
         :param *args:    The body of the reply
         :param **kwargs: Keyword arguments of the Reply constructor
+
+        :return: Returns whether reply was sent successfully
+        :rtype: bool
         """
-        await self._sender.send_message(self, Reply(*args, **kwargs))
+        return await self._sender.reply_message(self, Reply(*args, **kwargs))
 
     async def typing_started(self) -> None:
         """Send a typing started message."""
@@ -94,10 +94,6 @@ class Message:
         """Send a typing stopped message."""
         await self._sender.typing_stopped(self)
 
-    async def mark_delivered(self) -> None:
-        """Mark the message as delivered."""
-        await self._sender.mark_delivered(self)
-
     async def mark_read(self) -> None:
         """Mark the message as read."""
         await self._sender.mark_read(self)
