@@ -27,11 +27,15 @@ import anyio.abc
 class Socket:
     """This object represents a signald socket."""
 
-    def __init__(self, username: str, socket_path: str = "/var/run/signald/signald.sock"):
+    def __init__(self,
+                 username: str,
+                 socket_path: str = "/var/run/signald/signald.sock",
+                 subscribe: bool = False):
         """Initialize socket."""
         self._username: str = username
         self._socket_path: str = socket_path
         self._socket: anyio.abc.SocketStream
+        self._subscribe: bool = subscribe
 
         self.log = logging.getLogger(__name__)
 
@@ -39,12 +43,16 @@ class Socket:
         """Connect to the socket."""
         self._socket = await (await anyio.connect_unix(self._socket_path)).__aenter__()
         self.log.info(f"Connected to socket ({self._socket_path})")
-        await self.send({"type": "subscribe", "username": self._username})
-        self.log.info(f"Bot attempted to subscribe to +********{self._username[-3:]}")
+
+        if self._subscribe:
+            await self.send({"type": "subscribe", "username": self._username})
+            self.log.info(f"Bot attempted to subscribe to +********{self._username[-3:]}")
         return self
 
     async def __aexit__(self, *excinfo):
         """Disconnect from the internal socket."""
+        await self.send({"type": "unsubscribe", "username": self._username})
+        self.log.info(f"Bot attempted to unsubscribe to +********{self._username[-3:]}")
         return await self._socket.__aexit__(*excinfo)
 
     async def read(self) -> AsyncIterable[bytes]:
